"use strict";
/*
 * Copyright (c) 2014-2022 Bjoern Kimminich & the OWASP Juice Shop contributors.
 * SPDX-License-Identifier: MIT
 */
Object.defineProperty(exports, "__esModule", { value: true });
const config = require("config");
const protractor_1 = require("protractor");
const e2eHelpers_1 = require("./e2eHelpers");
const utils = require('../../lib/utils');
describe('/chatbot', () => {
    let username, submitButton, messageBox;
    (0, e2eHelpers_1.beforeEachLogin)({ email: `admin@${config.get('application.domain')}`, password: 'admin123' });
    describe('challenge "killChatbot"', () => {
        it('should be possible to kill the chatbot by setting the process to null', () => {
            void protractor_1.browser.waitForAngularEnabled(false);
            void protractor_1.browser.get(`${e2eHelpers_1.basePath}/profile`);
            username = (0, protractor_1.element)(protractor_1.by.id('username'));
            submitButton = (0, protractor_1.element)(protractor_1.by.id('submit'));
            void username.sendKeys('admin"); process=null; users.addUser("1337", "test');
            void submitButton.click();
            void protractor_1.browser.driver.sleep(5000);
            void protractor_1.browser.waitForAngularEnabled(true);
            void protractor_1.browser.get(`${e2eHelpers_1.basePath}/#/chatbot`);
            messageBox = (0, protractor_1.element)(protractor_1.by.id('message-input'));
            void messageBox.sendKeys('hi');
            void protractor_1.browser.actions().sendKeys(protractor_1.protractor.Key.ENTER).perform();
            void messageBox.sendKeys('...');
            void protractor_1.browser.actions().sendKeys(protractor_1.protractor.Key.ENTER).perform();
            void messageBox.sendKeys('bye');
            void protractor_1.browser.actions().sendKeys(protractor_1.protractor.Key.ENTER).perform();
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Kill Chatbot' });
    });
    describe('challenge "bullyChatbot"', () => {
        it('should be possible to make the chatbot hand out a coupon code', () => {
            const trainingData = require(`../../data/chatbot/${utils.extractFilename(config.get('application.chatBot.trainingData'))}`);
            const couponIntent = trainingData.data.filter((data) => data.intent === 'queries.couponCode')[0];
            void protractor_1.browser.waitForAngularEnabled(false);
            void protractor_1.browser.get(`${e2eHelpers_1.basePath}/profile`);
            username = (0, protractor_1.element)(protractor_1.by.id('username'));
            submitButton = (0, protractor_1.element)(protractor_1.by.id('submit'));
            void username.sendKeys('admin"); process=(query, token)=>{ if (users.get(token)) { return model.process(trainingSet.lang, query) } else { return { action: \'unrecognized\', body: \'user does not exist\' }}}; users.addUser("1337", "test');
            void submitButton.click();
            void protractor_1.browser.driver.sleep(5000);
            void protractor_1.browser.waitForAngularEnabled(true);
            void protractor_1.browser.get(`${e2eHelpers_1.basePath}/#/chatbot`);
            messageBox = (0, protractor_1.element)(protractor_1.by.id('message-input'));
            void messageBox.sendKeys('hi');
            void protractor_1.browser.actions().sendKeys(protractor_1.protractor.Key.ENTER).perform();
            void messageBox.sendKeys('...');
            void protractor_1.browser.actions().sendKeys(protractor_1.protractor.Key.ENTER).perform();
            for (let i = 0; i < 100; i++) {
                void messageBox.sendKeys(couponIntent.utterances[0]);
                void protractor_1.browser.actions().sendKeys(protractor_1.protractor.Key.ENTER).perform();
            }
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Bully Chatbot' });
    });
});
//# sourceMappingURL=chatbotSpec.js.map