"use strict";
/*
 * Copyright (c) 2014-2022 Bjoern Kimminich & the OWASP Juice Shop contributors.
 * SPDX-License-Identifier: MIT
 */
Object.defineProperty(exports, "__esModule", { value: true });
const config = require("config");
const protractor_1 = require("protractor");
const e2eHelpers_1 = require("./e2eHelpers");
const utils = require('../../lib/utils');
let blueprint;
for (const product of config.get('products')) {
    if (product.fileForRetrieveBlueprintChallenge) {
        blueprint = product.fileForRetrieveBlueprintChallenge;
        break;
    }
}
describe('/', () => {
    describe('challenge "easterEgg2"', () => {
        it('should be able to access "secret" url for easter egg', () => {
            void protractor_1.browser.driver.get(`${protractor_1.browser.baseUrl}/the/devs/are/so/funny/they/hid/an/easter/egg/within/the/easter/egg`);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Nested Easter Egg' });
    });
    describe('challenge "premiumPaywall"', () => {
        it('should be able to access "super secret" url for premium content', () => {
            void protractor_1.browser.driver.get(`${protractor_1.browser.baseUrl}/this/page/is/hidden/behind/an/incredibly/high/paywall/that/could/only/be/unlocked/by/sending/1btc/to/us`);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Premium Paywall' });
    });
    describe('challenge "privacyPolicyProof"', () => {
        it('should be able to access proof url for reading the privacy policy', () => {
            void protractor_1.browser.driver.get(`${protractor_1.browser.baseUrl}/we/may/also/instruct/you/to/refuse/all/reasonably/necessary/responsibility`);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Privacy Policy Inspection' });
    });
    describe('challenge "extraLanguage"', () => {
        it('should be able to access the Klingon translation file', () => {
            void protractor_1.browser.driver.get(`${protractor_1.browser.baseUrl}/assets/i18n/tlh_AA.json`);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Extra Language' });
    });
    describe('challenge "retrieveBlueprint"', () => {
        it('should be able to access the blueprint file', () => {
            void protractor_1.browser.driver.get(`${protractor_1.browser.baseUrl}/assets/public/images/products/${blueprint}`);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Retrieve Blueprint' });
    });
    describe('challenge "missingEncoding"', () => {
        it('should be able to access the crazy cat photo', () => {
            void protractor_1.browser.driver.get(`${protractor_1.browser.baseUrl}/assets/public/images/uploads/%F0%9F%98%BC-%23zatschi-%23whoneedsfourlegs-1572600969477.jpg`);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Missing Encoding' });
    });
    describe('challenge "securityPolicy"', () => {
        it('should be able to access the security.txt file', () => {
            void protractor_1.browser.driver.get(`${protractor_1.browser.baseUrl}/.well-known/security.txt`);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Security Policy' });
    });
    describe('challenge "emailLeak"', () => {
        it('should be able to request the callback on /rest/user/whoami', () => {
            void protractor_1.browser.driver.get(`${protractor_1.browser.baseUrl}/rest/user/whoami?callback=func`);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Email Leak' });
    });
    describe('challenge "accessLogDisclosure"', () => {
        it('should be able to access today\'s access log file', () => {
            void protractor_1.browser.driver.get(`${protractor_1.browser.baseUrl}/support/logs/access.log.${utils.toISO8601(new Date())}`);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Access Log' });
    });
});
//# sourceMappingURL=directAccessSpec.js.map