"use strict";
/*
 * Copyright (c) 2014-2022 Bjoern Kimminich & the OWASP Juice Shop contributors.
 * SPDX-License-Identifier: MIT
 */
Object.defineProperty(exports, "__esModule", { value: true });
const config = require("config");
const protractor_1 = require("protractor");
const e2eHelpers_1 = require("./e2eHelpers");
describe('/#/forgot-password', () => {
    let email, securityAnswer, newPassword, newPasswordRepeat, resetButton;
    const EC = protractor_1.protractor.ExpectedConditions;
    beforeEach(() => {
        void (0, protractor_1.$)('#logout').isPresent().then((result) => {
            if (result) {
                void (0, protractor_1.$)('#logout').click();
            }
        });
        void protractor_1.browser.wait(EC.stalenessOf((0, protractor_1.$)('#logout')), 5000);
        void protractor_1.browser.get(`${e2eHelpers_1.basePath}/#/forgot-password`);
        email = (0, protractor_1.element)(protractor_1.by.id('email'));
        securityAnswer = (0, protractor_1.element)(protractor_1.by.id('securityAnswer'));
        newPassword = (0, protractor_1.element)(protractor_1.by.id('newPassword'));
        newPasswordRepeat = (0, protractor_1.element)(protractor_1.by.id('newPasswordRepeat'));
        resetButton = (0, protractor_1.element)(protractor_1.by.id('resetButton'));
    });
    describe('as Jim', () => {
        it('should be able to reset password with his security answer', () => {
            void email.sendKeys(`jim@${config.get('application.domain')}`);
            void protractor_1.browser.wait(EC.elementToBeClickable(securityAnswer), 2000, 'Security answer field did not become visible');
            void securityAnswer.sendKeys('Samuel');
            void newPassword.sendKeys('I <3 Spock');
            void newPasswordRepeat.sendKeys('I <3 Spock');
            void resetButton.click();
            expect((0, protractor_1.$)('.confirmation').getAttribute('hidden')).not.toBeTruthy();
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Reset Jim\'s Password' });
    });
    describe('as Bender', () => {
        it('should be able to reset password with his security answer', () => {
            void email.sendKeys(`bender@${config.get('application.domain')}`);
            void protractor_1.browser.wait(EC.elementToBeClickable(securityAnswer), 2000, 'Security answer field did not become visible');
            void securityAnswer.sendKeys('Stop\'n\'Drop');
            void newPassword.sendKeys('Brannigan 8=o Leela');
            void newPasswordRepeat.sendKeys('Brannigan 8=o Leela');
            void resetButton.click();
            expect((0, protractor_1.$)('.confirmation').getAttribute('hidden')).not.toBeTruthy();
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Reset Bender\'s Password' });
    });
    describe('as Bjoern', () => {
        describe('for his internal account', () => {
            it('should be able to reset password with his security answer', () => {
                void email.sendKeys(`bjoern@${config.get('application.domain')}`);
                void protractor_1.browser.wait(EC.elementToBeClickable(securityAnswer), 2000, 'Security answer field did not become visible');
                void securityAnswer.sendKeys('West-2082');
                void newPassword.sendKeys('monkey birthday ');
                void newPasswordRepeat.sendKeys('monkey birthday ');
                void resetButton.click();
                expect((0, protractor_1.$)('.confirmation').getAttribute('hidden')).not.toBeTruthy();
            });
            (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Reset Bjoern\'s Password' });
        });
        describe('for his OWASP account', () => {
            it('should be able to reset password with his security answer', () => {
                void email.sendKeys('bjoern@owasp.org');
                void protractor_1.browser.wait(EC.elementToBeClickable(securityAnswer), 2000, 'Security answer field did not become visible');
                void securityAnswer.sendKeys('Zaya');
                void newPassword.sendKeys('kitten lesser pooch');
                void newPasswordRepeat.sendKeys('kitten lesser pooch');
                void resetButton.click();
                expect((0, protractor_1.$)('.confirmation').getAttribute('hidden')).not.toBeTruthy();
            });
            (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Bjoern\'s Favorite Pet' });
        });
    });
    describe('as Morty', () => {
        it('should be able to reset password with his security answer', () => {
            void email.sendKeys(`morty@${config.get('application.domain')}`);
            void protractor_1.browser.wait(EC.elementToBeClickable(securityAnswer), 2000, 'Security answer field did not become visible');
            void securityAnswer.sendKeys('5N0wb41L');
            void newPassword.sendKeys('iBurri3dMySe1f!');
            void newPasswordRepeat.sendKeys('iBurri3dMySe1f!');
            void resetButton.click();
            expect((0, protractor_1.$)('.confirmation').getAttribute('hidden')).not.toBeTruthy();
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Reset Morty\'s Password' });
    });
    describe('as Uvogin', () => {
        it('should be able to reset password with his security answer', () => {
            void email.sendKeys(`uvogin@${config.get('application.domain')}`);
            void protractor_1.browser.wait(EC.elementToBeClickable(securityAnswer), 2000, 'Security answer field did not become visible');
            void securityAnswer.sendKeys('Silence of the Lambs');
            void newPassword.sendKeys('ora-ora > muda-muda');
            void newPasswordRepeat.sendKeys('ora-ora > muda-muda');
            void resetButton.click();
            expect((0, protractor_1.$)('.confirmation').getAttribute('hidden')).not.toBeTruthy();
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Reset Uvogin\'s Password' });
    });
});
//# sourceMappingURL=forgotPasswordSpec.js.map