"use strict";
/*
 * Copyright (c) 2014-2022 Bjoern Kimminich & the OWASP Juice Shop contributors.
 * SPDX-License-Identifier: MIT
 */
Object.defineProperty(exports, "__esModule", { value: true });
const config = require("config");
const protractor_1 = require("protractor");
const e2eHelpers_1 = require("./e2eHelpers");
describe('/#/photo-wall', () => {
    let email, securityAnswer, newPassword, newPasswordRepeat, resetButton;
    const EC = protractor_1.protractor.ExpectedConditions;
    beforeEach(() => {
        void (0, protractor_1.$)('#logout').isPresent().then((result) => {
            if (result) {
                void (0, protractor_1.$)('#logout').click();
            }
        });
        void protractor_1.browser.wait(EC.stalenessOf((0, protractor_1.$)('#logout')), 5000);
        void protractor_1.browser.get(`${e2eHelpers_1.basePath}/#/forgot-password`);
        email = (0, protractor_1.element)(protractor_1.by.id('email'));
        securityAnswer = (0, protractor_1.element)(protractor_1.by.id('securityAnswer'));
        newPassword = (0, protractor_1.element)(protractor_1.by.id('newPassword'));
        newPasswordRepeat = (0, protractor_1.element)(protractor_1.by.id('newPasswordRepeat'));
        resetButton = (0, protractor_1.element)(protractor_1.by.id('resetButton'));
    });
    describe('challenge "geoStalkingMeta"', () => {
        it('Should be possible to find the answer to a security question in the meta-data of a photo on the photo wall', () => {
            const answer = ((() => {
                const memories = config.get('memories');
                for (let i = 0; i < memories.length; i++) {
                    if (memories[i].geoStalkingMetaSecurityAnswer) {
                        return memories[i].geoStalkingMetaSecurityAnswer;
                    }
                }
            })());
            void email.sendKeys(`john@${config.get('application.domain')}`);
            void protractor_1.browser.wait(EC.elementToBeClickable(securityAnswer), 2000, 'Security answer field did not become visible');
            void securityAnswer.sendKeys(answer);
            void newPassword.sendKeys('123456');
            void newPasswordRepeat.sendKeys('123456');
            void resetButton.click();
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Meta Geo Stalking' });
    });
    describe('challenge "geoStalkingVisual"', () => {
        it('Should be possible to determine the answer to a security question by looking closely at an image on the photo wall', () => {
            const answer = ((() => {
                const memories = config.get('memories');
                for (let i = 0; i < memories.length; i++) {
                    if (memories[i].geoStalkingVisualSecurityAnswer) {
                        return memories[i].geoStalkingVisualSecurityAnswer;
                    }
                }
            })());
            void email.sendKeys(`emma@${config.get('application.domain')}`);
            void protractor_1.browser.wait(EC.elementToBeClickable(securityAnswer), 2000, 'Security answer field did not become visible');
            void securityAnswer.sendKeys(answer);
            void newPassword.sendKeys('123456');
            void newPasswordRepeat.sendKeys('123456');
            void resetButton.click();
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Visual Geo Stalking' });
    });
});
//# sourceMappingURL=geoStalkingSpec.js.map