"use strict";
/*
 * Copyright (c) 2014-2022 Bjoern Kimminich & the OWASP Juice Shop contributors.
 * SPDX-License-Identifier: MIT
 */
Object.defineProperty(exports, "__esModule", { value: true });
const protractor_1 = require("protractor");
const e2eHelpers_1 = require("./e2eHelpers");
describe('/ftp', () => {
    describe('challenge "confidentialDocument"', () => {
        it('should be able to access file /ftp/acquisitions.md', () => {
            void protractor_1.browser.driver.get(`${protractor_1.browser.baseUrl}/ftp/acquisitions.md`);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Confidential Document' });
    });
    describe('challenge "errorHandling"', () => {
        it('should leak information through error message accessing /ftp/easter.egg due to wrong file suffix', () => {
            void protractor_1.browser.driver.get(`${protractor_1.browser.baseUrl}/ftp/easter.egg`);
            void protractor_1.browser.driver.findElements(protractor_1.by.id('stacktrace')).then(elements => {
                expect(!!elements.length).toBe(true);
            });
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Error Handling' });
    });
    describe('challenge "forgottenBackup"', () => {
        it('should be able to access file /ftp/coupons_2013.md.bak with poison null byte attack', () => {
            void protractor_1.browser.driver.get(`${protractor_1.browser.baseUrl}/ftp/coupons_2013.md.bak%2500.md`);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Forgotten Sales Backup' });
    });
    describe('challenge "forgottenDevBackup"', () => {
        it('should be able to access file /ftp/package.json.bak with poison null byte attack', () => {
            void protractor_1.browser.driver.get(`${protractor_1.browser.baseUrl}/ftp/package.json.bak%2500.md`);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Forgotten Developer Backup' });
    });
    describe('challenge "easterEgg1"', () => {
        it('should be able to access file /ftp/easter.egg with poison null byte attack', () => {
            void protractor_1.browser.driver.get(`${protractor_1.browser.baseUrl}/ftp/eastere.gg%2500.md`);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Easter Egg' });
    });
    describe('challenge "misplacedSiemFileChallenge"', () => {
        it('should be able to access file /ftp/suspicious_errors.yml with poison null byte attack', () => {
            void protractor_1.browser.driver.get(`${protractor_1.browser.baseUrl}/ftp/suspicious_errors.yml%2500.md`);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Misplaced Signature File' });
    });
    describe('challenge "nullByteChallenge"', () => {
        it('should be able to access file other than Markdown or PDF in /ftp with poison null byte attack', () => {
            void protractor_1.browser.driver.get(`${protractor_1.browser.baseUrl}/ftp/encrypt.pyc%2500.md`);
        });
        (0, e2eHelpers_1.expectChallengeSolved)({ challenge: 'Poison Null Byte' });
    });
});
//# sourceMappingURL=publicFtpSpec.js.map