"use strict";
/*
 * Copyright (c) 2014-2022 Bjoern Kimminich & the OWASP Juice Shop contributors.
 * SPDX-License-Identifier: MIT
 */
Object.defineProperty(exports, "__esModule", { value: true });
const config = require("config");
const protractor_1 = require("protractor");
const e2eHelpers_1 = require("./e2eHelpers");
const otplib = require('otplib');
const EC = protractor_1.protractor.ExpectedConditions;
describe('/#/basket', () => {
    let successMessage;
    let setupInstructions;
    let currentPasswordSetup;
    let currentPasswordDisable;
    let initalToken;
    let setupSubmit;
    let disableSubmit;
    beforeEach(() => {
        successMessage = (0, protractor_1.element)(protractor_1.by.id('2fa-setup-successfully'));
        setupInstructions = (0, protractor_1.element)(protractor_1.by.id('2fa-setup-instructions'));
        currentPasswordSetup = (0, protractor_1.element)(protractor_1.by.id('currentPasswordSetup'));
        currentPasswordDisable = (0, protractor_1.element)(protractor_1.by.id('currentPasswordDisable'));
        initalToken = (0, protractor_1.element)(protractor_1.by.id('initalToken'));
        setupSubmit = (0, protractor_1.element)(protractor_1.by.id('setupTwoFactorAuth'));
        disableSubmit = (0, protractor_1.element)(protractor_1.by.id('disableTwoFactorAuth'));
    });
    describe('as wurstbrot', () => {
        (0, e2eHelpers_1.beforeEachLogin)({
            email: `wurstbrot@${config.get('application.domain')}`,
            password: 'EinBelegtesBrotMitSchinkenSCHINKEN!',
            totpSecret: 'IFTXE3SPOEYVURT2MRYGI52TKJ4HC3KH'
        });
        it('should show an success message for 2fa enabled accounts', () => {
            void protractor_1.browser.get(`${e2eHelpers_1.basePath}/#/privacy-security/two-factor-authentication`);
            void protractor_1.browser.wait(EC.visibilityOf(successMessage), 5000, '2FA success message didnt show up for an 2fa enabled account in time');
        });
    });
    describe('as amy', () => {
        (0, e2eHelpers_1.beforeEachLogin)({ email: `amy@${config.get('application.domain')}`, password: 'K1f.....................' });
        it('should be possible to setup 2fa for a account without 2fa enabled', async () => {
            void protractor_1.browser.get(`${e2eHelpers_1.basePath}/#/privacy-security/two-factor-authentication`);
            void protractor_1.browser.wait(EC.visibilityOf(setupInstructions), 5000, '2FA setup instructions should show up for users without 2fa enabled');
            const secret = await initalToken.getAttribute('data-test-totp-secret');
            void currentPasswordSetup.sendKeys('K1f.....................');
            void initalToken.sendKeys(otplib.authenticator.generate(secret));
            void setupSubmit.click();
            void protractor_1.browser.wait(EC.visibilityOf(successMessage), 5000, 'success message didnt show up in time after enabling 2fa for an account');
            void currentPasswordDisable.sendKeys('K1f.....................');
            void disableSubmit.click();
            void protractor_1.browser.wait(EC.visibilityOf(setupInstructions), 5000, '2FA setup instructions should show up after users disabled their accounts');
        });
    });
});
//# sourceMappingURL=totpSetupSpec.js.map