# sequelize-notupdate-attributes

A very simple [Sequelize](https://github.com/sequelize/sequelize) plugin which adds **no update** and **readonly** attributes support. Compatible with sequelize v6.

# Warning

The project is based on the repository [node-sequelize-notupdate-attributes](https://github.com/diosney/node-sequelize-notupdate-attributes), now compatible with v6 of sequelize.

## Prerequisites

Have previously installed the `sequelize` package in the project.

## Install

Using npm:

```sh
npm install --save sequelize-notupdate-attributes
```

Using yarn:

```sh
yarn add -D sequelize-notupdate-attributes
```

## Usage

Add the plugin to the sequelize instance and then set the noupdate
properties in your models, as shown in the basic example below:

```js
var sequelizeNoUpdateAttributes = require('sequelize-notupdate-attributes');

var sequelize = new Sequelize('database', 'user', 'password');
sequelizeNoUpdateAttributes(sequelize); // Note that is the `sequelize` instance the passed reference.

var Post = sequelize.define('Post', {
  content: {
    type: Sequelize.STRING,
    noUpdate: true,
  },
});
```

What this do is to mark the `content` attribute so if an update is done, then:

- if the field previous value is null, it will accept the change
- if the field previous value is not null, it will trigger a `SequelizeValidationErrorItem` error.

so, the `content` field becomes a **readonly** after its becomes not null.

Works too with foreign key fields in associations:

```js
models.Post.belongsTo(models.Person, {
  as: 'Creator',
  foreignKey: {
    allowNull: false,
    noUpdate: true, // Will mark the `CreatorId` field to be `noUpdate`d.
  },
});
```

### Readonly attributes

If you do want truly **readonly** attributes with no modifications at all
being allowed, you can use the `readonly` option as shown below:

```js
var Post = sequelize.define('Post', {
  content: {
    type: Sequelize.STRING,
    noUpdate: {
      readOnly: true,
    },
  },
});
```

which effectively disables any modification on the `content` attribute,
no matter if the previous value was null or not, though exception is
when the record is new.

## Issues

The source is available for download from [GitHub](https://github.com/daviddossantos/sequelize-notupdate-attributes)
and there is a [issue tracker](https://github.com/daviddossantos/sequelize-notupdate-attributes/issues) so you can report bugs there.

## Tests

To run the tests just execute `yarn test`.

## License

The MIT License (MIT)
